Class: FZip::Adapter

Inherits:
Object
  • Object
show all
Defined in:
lib/fzip/adapter.rb

Instance Method Summary collapse

Instance Method Details

#branch?(node) ⇒ Boolean

Can the node have children

Returns true if the node can have even if it currently doesn’t.

Returns:

  • (Boolean)


6
7
# File 'lib/fzip/adapter.rb', line 6

def branch?(node)
end

#children(node) ⇒ Object

The children of a node

Return an array, or an object that responds to first, drop and +



12
13
# File 'lib/fzip/adapter.rb', line 12

def children(node)
end

#make_node(node, children) ⇒ Object

Given a node and an array of children, returns a new branch node of the same type with the supplied children.



17
18
# File 'lib/fzip/adapter.rb', line 17

def make_node(node, children)
end